@@ -13,17 +13,19 @@
 #' @examples
 #' \dontrun{
 #'   # Retrieve mopex daily catalogue
-#'   url <- "ftp://hydrology.nws.noaa.gov/pub/gcip/mopex/US_Data/Us_438_Daily"
+#'   url <- "ftp://hydrology.nws.noaa.gov/pub/gcip/mopex/US_Data/Us_438_Daily/"
 #'   getContent(dirs = url)
 #' }
 #'
 
 getContent <- function(dirs) {
 
-  urls <- paste(dirs, "/", sep = "")
-  fls <- strsplit(RCurl::getURL(urls, dirlistonly = TRUE), "\n")
-  ok <- vapply(fls, length) > 0
-  links <- unlist(mapply(paste, urls[ok], fls[ok], sep = "", SIMPLIFY = FALSE),
+  # Get names of files
+  fls <- strsplit(RCurl::getURL(dirs, dirlistonly = TRUE), "\n")[[1]]
+  # Keep only files with extension .dly
+  fls_dly <- fls[grepl(pattern = "*.dly", x = fls)]
+  # Combine with url to get full path
+  links <- unlist(mapply(paste, dirs, fls_dly, sep = "", SIMPLIFY = FALSE),
                   use.names = FALSE)
 
   return(links)
